# automacao-blaze

Automação do site Blaze.bet usando Selenium e WebDriver Manager.

## Instalação

```bash
pip install roleta-automatica
```

## Uso

```python
from roleta_automatica import RoletaBrasileira

bot = RoletaBrasileira("email", "senha", "https://blaze.bet.br/pt/games/roleta-brasileira")
```
